@@ -38,9 +38,11 @@ gt_html_to_raster <- function(filename,
   #### Convert .html to png
   filename_root <- filename %>% str_replace_all(".html$", "")
   filename_only <- basename(filename_root)
+  #filename_dir  <- filename_root %>% stringr::str_replace_all(paste0("/", filename_only), "")
   filename_dir  <- filename_root %>% 
-    stringr::str_replace_all(paste0("/", filename_only), "")
-  
+    stringr::str_replace_all(filename_only, "") %>%
+    stringr::str_sub(end = -2)
+
   if(print_progress){
     cat(paste0("Pausing for ", webshot_delay, " seconds to allow traffic data to render"))
   }
